/*
    w32loader
    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __OLEAUT32_H__
#define __OLEAUT32_H__


#include "w32ldr.h"


G_BEGIN_DECLS


#include "ole32.h"
typedef struct _ITypeLib ITypeLib;
typedef enum _REGKIND
{
  REGKIND_DEFAULT,
  REGKIND_REGISTER,
  REGKIND_NONE
} REGKIND;


extern W32LdrExport w32ldr_oleaut32_exports[];


HRESULT WINAPI LoadTypeLib (LPCOLESTR szFile, ITypeLib **pptLib);
HRESULT WINAPI LoadTypeLibEx (LPCOLESTR szFile, REGKIND regkind, ITypeLib **pptLib);
HRESULT WINAPI RegisterTypeLib (ITypeLib *ptlib, OLECHAR *szFullPath, OLECHAR *szHelpDir);


G_END_DECLS


#endif /* __OLEAUT32_H__ */
